[![Build Status](https://travis-ci.com/plasticuproject/fnv1a.svg?branch=master)](https://travis-ci.com/plasticuproject/fnv1a)
[![Python 3.7](https://img.shields.io/badge/python-3.6+-blue.svg)](https://www.python.org/downloads/release/python-370/)
![GitHub](https://img.shields.io/github/license/plasticuproject/fnv1a)
[![PyPI version](https://badge.fury.io/py/fnv1a.svg)](https://badge.fury.io/py/fnv1a)
[![Downloads](https://pepy.tech/badge/fnv1a)](https://pepy.tech/project/fnv1a)
[![Coverage Status](https://coveralls.io/repos/github/plasticuproject/fnv1a/badge.svg?branch=master)](https://coveralls.io/github/plasticuproject/fnv1a?branch=master)
[![Language grade: Python](https://img.shields.io/lgtm/grade/python/g/plasticuproject/fnv1a.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/plasticuproject/fnv1a/context:python)
[![Quality Gate Status](https://sonarcloud.io/api/project_badges/measure?project=plasticuproject_fnv1a&metric=alert_status)](https://sonarcloud.io/dashboard?id=plasticuproject_fnv1a)
[![Security Rating](https://sonarcloud.io/api/project_badges/measure?project=plasticuproject_fnv1a&metric=security_rating)](https://sonarcloud.io/dashboard?id=plasticuproject_fnv1a)

# fnv1a

I'm always talking shit about Object Oriented Programming. Well to show that I can 
actually write a little OOP (I just choose not to do so most of the time), I 
implimented a 64 bit FNV-1a hashing algorithm, class based, with objects and instances 
and all that crap, into a python module. It's completely useless and ridiculous and 
it makes no sense, but I was really bored.

```pip install fnv1a```

